import Mock from 'mockjs';
import FetchMock from 'fetch-mock';

/**
 * 自定义mock方法示例
 */
Mock.Random.extend({
  techs: [
    'react',
    'redux',
    'react-redux',
    'react-router',
    'fetch',
    'mockJs',
    'antDesign',
  ],
  tech() {
    return this.shuffle(this.techs);
  },
});

/**
 * ajax拦截示例
 * 支持 get、post、put、delete
 */
// Mock.mock(/technology\/list/, 'get', (options) => {
//   console.log(`%c${options.url}`, 'color:blue');
//   return Mock.mock({
//     meta: {
//       code: 'SC_200',
//       message: 'OK',
//     },
//     data: '@TECH',
//   });
// });

/**
 * fetch拦截示例
 * 支持 get(), post(), put(), delete(), head(), patch()
 */
FetchMock.get(/technology\/list/, (url) => {
  console.log(`%c${url}`, 'color:blue');
  return Mock.mock({
    meta: {
      code: 'SC_200',
      message: 'OK',
    },
    data: '@TECH',
  });
});

FetchMock.get(/technology/, (url) => {
  console.log(`%c${url}`, 'color:blue');
  const idx = url.lastIndexOf('/');
  const name = url.substring(idx + 1);
  const description = (() => {
    switch (name) {
      case 'react':
        return '一个用于构建用户界面的 JAVASCRIPT 库';
      case 'redux':
        return '一个可预测状态的容器';
      case 'react-redux':
        return '连接react和redux';
      case 'react-router':
        return '一种路由机制';
      case 'fetch':
        return '调用服务器接口';
      case 'mockJs':
        return '模拟服务器接口数据';
      case 'antDesign':
        return '一个UI组件库';
      default:
        return '暂无';
    }
  })();
  return Mock.mock({
    meta: {
      code: 'SC_200',
      message: 'OK',
    },
    data: `${description} - By @cname`,
  });
});

